@@ -1,6 +1,7 @@
 package Nefarious; 
-our $VERSION = '0.02'; use 5.006; use strict; use warnings;
+use 5.006; use strict; use warnings;
 use Factory::Sub; use Tie::IxHash; our %META;
+our $VERSION = '0.03'; 
 
 BEGIN {
 	tie %META, 'Tie::IxHash';
